"""Control window"""
import time

import BRoster
import BWindow
import BListView
import BScrollView
import BStringItem
import BMessage
import BBox
import BStringView

from AppKit import *
from InterfaceKit import *

from modules.constants import *
from modules.config import Account
from modules.config import Configuration
from modules.ui import *
import modules.util
from dialogs import *

import modules.ui

from widgets import *
from menus import MainMenu
from constants import *

# Main window
class ControlWindow(BWindow.BWindow):
	"""The control window"""
	def __init__(self, x,y):
		BWindow.BWindow.__init__(self, (x,y,0,0), 'Offline', B_TITLED_WINDOW,
			B_QUIT_ON_WINDOW_CLOSE|B_ASYNCHRONOUS_CONTROLS)
		bounds = self.Bounds()
		# Main menubar
		bar = MainMenu(bounds)
		self.AddChild(bar)
		barbounds = bar.Bounds()
		box = BBox.BBox((0,barbounds[3]+1,bounds[2],bounds[3]), 'boundingbox', B_FOLLOW_ALL, B_FULL_UPDATE_ON_RESIZE|B_WILL_DRAW, B_NO_BORDER)
		boxbounds = box.Bounds()
		self.AddChild(box)
		cbox = ConnectionBox((5,5,boxbounds[2]-5,boxbounds[3]-5))
		box.AddChild(cbox)
		cframe = cbox.Frame()
		pbox = PresenceBox((5,cframe[3]+5,boxbounds[2]-5,boxbounds[3]-5))
		box.AddChild(pbox)
		bframe = pbox.Frame()
		box.ResizeTo(bounds[2], bframe[3]+5)
		bframe = box.Frame()
		self.ResizeTo(300.0,bframe[3])

	### Hooks
	def MessageReceived(self,msg):
		if msg.what == B_ABOUT_REQUESTED:
			modules.ui.ShowAbout()
		elif msg.what == MSG_CONNECT:
			acc = Account(msg.FindString('account'))
			msg.AddString('user', acc.user)
			if acc.password is None:
				win = ModalPrompt('Password Prompt','Password')
				password = win.Go()
			else:
				password = acc.password
			if password is None or password.strip() == '':
				return
			msg.AddString('passwd', password)
			msg.AddString('resource', acc.resource)
			msg.AddInt32('port', acc.port)
			msg.AddString('host', acc.host)
			msg.AddBool('ssl', acc.ssl)
			BApplication.be_app.PostMessage(msg)
		elif msg.what == MSG_DISCONNECT:
			BApplication.be_app.PostMessage(msg)
		elif msg.what == INBOUND_PRESENCE:
			try:
				ptype = msg.FindString('type')
			except BMessage.error:
				ptype = None
			if ptype == 'subscribe':
				ShowSubscribeDlg(msg.FindString('from'), self, OUTBOUND_SUBSCRIBE_REPLY)
		elif msg.what == OUTBOUND_SUBSCRIBE_REPLY:
			which = msg.FindInt32('which')
			if which != 2:
				bmsg = BMessage.BMessage(OUTBOUND_PRESENCE)
				bmsg.AddString('to', msg.FindString('to'))
				bmsg.AddString('type', 'subscribed')
				BApplication.be_app.PostMessage(bmsg)
				if which == 0:
					bmsg = BMessage.BMessage(OUTBOUND_PRESENCE)
					bmsg.AddString('to', msg.FindString('to'))
					bmsg.AddString('type', 'subscribe')
					BApplication.be_app.PostMessage(bmsg)
			else:
				bmsg = BMessage.BMessage(OUTBOUND_PRESENCE)
				bmsg.AddString('to', msg.FindString('to'))
				bmsg.AddString('type', 'unsubscribed')
				BApplication.be_app.PostMessage(bmsg)
		elif msg.what == STATUS_CONNECTED:
			jid = msg.FindString('jid')
			# Change menus
			menubar = self.FindView('MainMenubar')
			item = menubar.FindItem('Disconnect')
			item.SetEnabled(True)
			item = menubar.FindItem('Connect')
			item.SetEnabled(False)
			item = menubar.FindItem('Presence')
			item.SetEnabled(True)
			box = self.FindView('connbox')
			box.setJID(jid)
			box.setResource(msg.FindString('resource'))
			box.setSSL(msg.FindBool('ssl'))
			bmsg = BMessage.BMessage(OUTBOUND_PRESENCE)
			# send default status
			conf = Configuration()
			defstat = conf.get('general', 'initstatus')
			entry = conf.get('presence', defstat)
			values = entry.split(',')
			bmsg.AddString('show', values[1].strip())
			bmsg.AddString('status', values[0].strip())
			if len(values) > 2:
				bmsg.AddString('priority', values[2].strip())
			#BApplication.be_app.PostMessage(bmsg)
			self.PostMessage(bmsg)
			#self.SetTitle(values[0].strip())
		elif msg.what == STATUS_DISCONNECTED:
			self.SetTitle('Offline')
			menubar = self.FindView('MainMenubar')
			item = menubar.FindItem('Disconnect')
			item.SetEnabled(False)
			item = menubar.FindItem('Connect')
			item.SetEnabled(True)
			item = menubar.FindItem('Presence')
			item.SetEnabled(False)
			pbox = self.FindView('prsbox')
			pbox.setShow('')
			pbox.setStatus('')
			pbox.setPriority('')
			cbox = self.FindView('connbox')
			cbox.setJID('')
			cbox.setResource('')
			cbox.setSSL(None)
		elif msg.what == OUTBOUND_PRESENCE:
			self.SetTitle(msg.FindString('status'))
			pbox = self.FindView('prsbox')
			pbox.setShow(msg.FindString('show'))
			pbox.setStatus(msg.FindString('status'))
			try:
				pbox.setPriority(msg.FindString('priority'))
			except BMessage.error:
				pbox.setPriority('0')
			BApplication.be_app.PostMessage(msg)
		elif msg.what == NEW_MESSAGE:
			BRoster.be_roster.Launch(SIG_JABBERMESSAGE)
		elif msg.what == LAUNCH_PREFS:
			modules.util.launchApp(SIG_PREFERENCES)

	def QuitRequested(self):
		return 1
