"""
Jabber connection class
Basicly only shuffling messages to and from the network but
also manages some tasks like version replies and roster management.
"""
import time
import socket

import jabber.jabber as jabber

from modules.log import log
from modules.constants import *
from constants import *
from modules.util import *

###########
### Classes
###########

class Roster:
	def __init__(self, user, password, host, port, ssl=False):
		self.ssl = ssl
		self.user = user
		self.password = password
		if self.ssl:
			self.client = jabber.Client(host=host, port=5223, connection=2)
		else:
			self.client = jabber.Client(host=host, port=port, connection=1)
		# Create a (fairly) unique resource
		self.resource = '%s-%s-%f' % (user,socket.gethostname(),time.time())
		self.client.setDisconnectHandler(self._disconnectHandler)

	def get(self):
		try:
			self.client.connect()
		except socket.error, (errno, errstr):
			log('socket error: %s' % errstr)
			return
		if not self.client.auth(self.user, self.password, self.resource):
			try:
				self.disconnect()
			except socket.error, (errno, errstr):
				log('socket error: %s' % errstr)
			return
		### Make ourselves invisible
		# Create privacy list
		iq = jabber.Iq(type='set')
		iq.setQuery('jabber:iq:privacy')
		payload = "<list name='invisible'><item action='deny' order='1'><presence-out/></item></list>"
		iq.setQueryPayload(payload)
		self.client.send(iq)
		# Activate privacy list
		iq = jabber.Iq(type='set')
		iq.setQuery('jabber:iq:privacy')
		payload = "<active name='invisible'/>"
		iq.setQueryPayload(payload)
		self.client.send(iq)
		# Send initial presence
		try:
			self.client.sendInitPresence()
		except socket.error, (errno, errstr):
			log('socket error: %s' % errstr)
			self.disconnect()
			return
		# Request roster
		roster = self.client.requestRoster()
		jids = roster.getJIDs()
		time.sleep(0.5)
		self.client.process(0)
		self.disconnect()
		rosterlist = []
		time.sleep(0.5)
		for jid in jids:
			rosterlist.append((jid,roster.getName(jid)))
		return rosterlist
	
	def disconnect(self):
# For some reason jabberpy's disconnect eats cpu here but doesnt
# in the main Hermod app. Weird.
# More reason to switch to pyxmpp maybe.
#		if not self.ssl:
#			try:
#				self.client.disconnect()
#			except socket.error, (errno, errstr):
#				log('socket error: %s' % errstr)
#		else:
		self.client.send(jabber.Presence(type='unavailable'))
		sock = self.client.getSocket()
		sock.send(u"</stream:stream>")
		try:
			sock.shutdown(2)
		except socket.error:
			print 'error shutting down socket'
		sock.close()

	def _disconnectHandler(self, con):
		self.connected = False
