#!/bin/sh
scriptdir=`dirname "$0"`

# Show Readme
/boot/beos/system/Tracker "$scriptdir/doc/Readme" &
alert "Please read the Readme file before proceeeding with the setup" "Ok, I'm done reading it"

# Identify executables
mimeset "$scriptdir"/Hermod
mimeset "$scriptdir"/JabberMessage
mimeset "$scriptdir"/JabberChat
mimeset "$scriptdir"/JabberContact
mimeset "$scriptdir"/Preferences
mimeset "$scriptdir"/RosterManager

DEFATTROPTS="-attrViewable 1 -attrEditable 0"

btn=`alert --warning "Create file type for Jabber messages?" "Yes" "No"`
if [ $btn == "Yes" ]; then
	SIG="text/x-jabbermsg"
	PREFAPPSIG="application/x-vnd.LimestoneSoftware.JabberMessage"
	SHORTNAME="Jabber Message"
	output=`setmime -add  $SIG -preferredAppSig $PREFAPPSIG -short  "$SHORTNAME" \
		-attribute "Jabber:From" -attrName "From" -attrWidth 96 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:Subject" -attrName "Subject" -attrWidth 128 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:MessageStatus" -attrName "Status" -attrWidth 32 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:Thread" -attrName "Thread" -attrWidth 64 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:MessageType" -attrName "Type" -attrWidth 32 -attrType CSTR $DEFATTROPTS`
	if [ X"$output" != X ]; then
		alert --info "Houston we have a problem: $output" "That sucks"
		exit 255
	fi
fi

btn=`alert --warning "Add attributes to Person file type?" "Yes" "No"`
if [ $btn == "Yes" ]; then
	SIG="application/x-person"
	output=`setmime -add $SIG \
		-attribute "Jabber:JID" -attrName "Jabber ID" -attrWidth 128 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:Status" -attrName "Jabber Status" -attrWidth 64 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:Online" -attrName "Jabber Online" -attrWidth 32 -attrType CSTR $DEFATTROPTS \
		-attribute "Jabber:Show" -attrName "Jabber Show" -attrWidth 32 -attrType CSTR $DEFATTROPTS`
	if [ X"$output" != X ]; then
		alert --info "Houston we have a problem: $output" "That sucks"
		exit 255
	fi
fi

btn=`alert --warning "Create indexes for Jabber messages?" "Yes" "No"`
if [ $btn == "Yes" ]; then
	mkindex -t string "Jabber:Online"
	mkindex -t string "Jabber:Status"
	mkindex -t string "Jabber:Show"
	mkindex -t string "Jabber:MessageType"
	mkindex -t string "Jabber:MessageStatus"
	mkindex -t string "Jabber:JID"
	mkindex -t string "Jabber:From"
fi

btn=`alert --warning "Create \"$HOME/jabber\" directory?" "Yes" "No"`
if [ $btn == "Yes" ]; then
	mkdir -p "$HOME"/jabber/In
	mkdir -p "$HOME"/jabber/Out
fi

btn=`alert --warning "Create \"$HOME/config/settings/Hermod\" and copy skeleton config files?" "Yes" "No"`
if [ $btn == "Yes" ]; then
	mkdir -p "$HOME"/config/settings/Hermod
	if [ ! -f "$HOME"/config/settings/Hermod/Preferences ]; then
		cp "$scriptdir"/settings/Preferences "$HOME"/config/settings/Hermod/
	fi
	if [ ! -f "$HOME"/config/settings/Hermod/Accounts ]; then
		cp "$scriptdir"/settings/Accounts "$HOME"/config/settings/Hermod/
	fi
fi

alert --info "Setup successfull" "Sweet"
